==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/mixer/v1/ReportRequestFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ReportRequestFluent<A extends ReportRequestFluent<A>> extends Fluent<A>{


    public A addToAttributes(int index,CompressedAttributes item);
    public A setToAttributes(int index,CompressedAttributes item);
    public A addToAttributes(CompressedAttributes... items);
    public A addAllToAttributes(Collection<CompressedAttributes> items);
    public A removeFromAttributes(CompressedAttributes... items);
    public A removeAllFromAttributes(Collection<CompressedAttributes> items);
    
/**
 * This method has been deprecated, please use method buildAttributes instead.
 * @return The buildable object.
 */
@Deprecated public List<CompressedAttributes> getAttributes();
    public List<CompressedAttributes> buildAttributes();
    public CompressedAttributes buildAttribute(int index);
    public CompressedAttributes buildFirstAttribute();
    public CompressedAttributes buildLastAttribute();
    public CompressedAttributes buildMatchingAttribute(io.fabric8.kubernetes.api.builder.Predicate<CompressedAttributesBuilder> predicate);
    public A withAttributes(List<CompressedAttributes> attributes);
    public A withAttributes(CompressedAttributes... attributes);
    public Boolean hasAttributes();
    public ReportRequestFluent.AttributesNested<A> addNewAttribute();
    public ReportRequestFluent.AttributesNested<A> addNewAttributeLike(CompressedAttributes item);
    public ReportRequestFluent.AttributesNested<A> setNewAttributeLike(int index,CompressedAttributes item);
    public ReportRequestFluent.AttributesNested<A> editAttribute(int index);
    public ReportRequestFluent.AttributesNested<A> editFirstAttribute();
    public ReportRequestFluent.AttributesNested<A> editLastAttribute();
    public ReportRequestFluent.AttributesNested<A> editMatchingAttribute(io.fabric8.kubernetes.api.builder.Predicate<CompressedAttributesBuilder> predicate);
    public A addToDefaultWords(int index,String item);
    public A setToDefaultWords(int index,String item);
    public A addToDefaultWords(String... items);
    public A addAllToDefaultWords(Collection<String> items);
    public A removeFromDefaultWords(String... items);
    public A removeAllFromDefaultWords(Collection<String> items);
    public List<String> getDefaultWords();
    public String getDefaultWord(int index);
    public String getFirstDefaultWord();
    public String getLastDefaultWord();
    public String getMatchingDefaultWord(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withDefaultWords(List<String> defaultWords);
    public A withDefaultWords(String... defaultWords);
    public Boolean hasDefaultWords();
    public Integer getGlobalWordCount();
    public A withGlobalWordCount(Integer globalWordCount);
    public Boolean hasGlobalWordCount();
    public A withNewGlobalWordCount(String arg1);
    public A withNewGlobalWordCount(int arg1);

    public interface AttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CompressedAttributesFluent<ReportRequestFluent.AttributesNested<N>>{

        
    public N and();    public N endAttribute();
}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/mixer/v1/ReportRequestFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ReportRequestFluent<A extends ReportRequestFluent<A>> extends Fluent<A>{


    public A addToAttributes(int index,CompressedAttributes item);
    public A setToAttributes(int index,CompressedAttributes item);
    public A addToAttributes(CompressedAttributes... items);
    public A addAllToAttributes(Collection<CompressedAttributes> items);
    public A removeFromAttributes(CompressedAttributes... items);
    public A removeAllFromAttributes(Collection<CompressedAttributes> items);
    public A removeMatchingFromAttributes(io.fabric8.kubernetes.api.builder.Predicate<CompressedAttributesBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildAttributes instead.
 * @return The buildable object.
 */
@Deprecated public List<CompressedAttributes> getAttributes();
    public List<CompressedAttributes> buildAttributes();
    public CompressedAttributes buildAttribute(int index);
    public CompressedAttributes buildFirstAttribute();
    public CompressedAttributes buildLastAttribute();
    public CompressedAttributes buildMatchingAttribute(io.fabric8.kubernetes.api.builder.Predicate<CompressedAttributesBuilder> predicate);
    public Boolean hasMatchingAttribute(io.fabric8.kubernetes.api.builder.Predicate<CompressedAttributesBuilder> predicate);
    public A withAttributes(List<CompressedAttributes> attributes);
    public A withAttributes(CompressedAttributes... attributes);
    public Boolean hasAttributes();
    public ReportRequestFluent.AttributesNested<A> addNewAttribute();
    public ReportRequestFluent.AttributesNested<A> addNewAttributeLike(CompressedAttributes item);
    public ReportRequestFluent.AttributesNested<A> setNewAttributeLike(int index,CompressedAttributes item);
    public ReportRequestFluent.AttributesNested<A> editAttribute(int index);
    public ReportRequestFluent.AttributesNested<A> editFirstAttribute();
    public ReportRequestFluent.AttributesNested<A> editLastAttribute();
    public ReportRequestFluent.AttributesNested<A> editMatchingAttribute(io.fabric8.kubernetes.api.builder.Predicate<CompressedAttributesBuilder> predicate);
    public A addToDefaultWords(int index,String item);
    public A setToDefaultWords(int index,String item);
    public A addToDefaultWords(String... items);
    public A addAllToDefaultWords(Collection<String> items);
    public A removeFromDefaultWords(String... items);
    public A removeAllFromDefaultWords(Collection<String> items);
    public List<String> getDefaultWords();
    public String getDefaultWord(int index);
    public String getFirstDefaultWord();
    public String getLastDefaultWord();
    public String getMatchingDefaultWord(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingDefaultWord(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withDefaultWords(List<String> defaultWords);
    public A withDefaultWords(String... defaultWords);
    public Boolean hasDefaultWords();
    public A addNewDefaultWord(String arg1);
    public A addNewDefaultWord(StringBuilder arg1);
    public A addNewDefaultWord(StringBuffer arg1);
    public Integer getGlobalWordCount();
    public A withGlobalWordCount(Integer globalWordCount);
    public Boolean hasGlobalWordCount();
    public RepeatedAttributesSemantics getRepeatedAttributesSemantics();
    public A withRepeatedAttributesSemantics(RepeatedAttributesSemantics repeatedAttributesSemantics);
    public Boolean hasRepeatedAttributesSemantics();

    public interface AttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CompressedAttributesFluent<ReportRequestFluent.AttributesNested<N>>{

        
    public N and();    public N endAttribute();
}


}
